## v0.9.0 (2025-02-11)

### ✨ Features

- improve fit_with_corr to update bounds iteratively (#26)
- add max option in start_dict kws for fit_with_corr method

### 🐞 Bug Fixes

- solve set method bound issue #28
- add bound_tol parameter to set_bounds for improved parameter limit handling (#27)
- update data plotting to use x values

[main fbf1ae8] bump: version 0.8.0 → 0.9.0
 2 files changed, 2 insertions(+), 2 deletions(-)

